@@ -19,29 +19,48 @@ class Strategy2Task(BaseTask):
 
         self.residue = 0
         self.strategy_df = None
+        self.account_task = AccountTask()
         self.update_account()
+        self.conn=self.engine.connect()
+
+
+
+
+
+
+
 
     def update_account(self):
-        AccountTask().refresh()
-        account = pd.read_sql(sql=f"select * from {AccountTask.table_name}", con=self.engine.connect())
+        self.account_task.refresh()
+        account = pd.read_sql(sql=f"select * from {AccountTask.table_name}", con=self.conn)
         for symbol in json.loads(account.to_json(orient='records')):
             if symbol['symbol'] == 'BUSD':
                 self.residue = symbol['free']
                 break
 
-        self.strategy_df = pd.read_sql(f"select * from {self.table.table_name} where status>2",
-                                       con=self.engine.connect())
+        self.strategy_df = pd.read_sql(f"select * from {self.table.table_name} where status=2",
+                                       con=self.conn)
+        time.sleep(1)
+
+    async def buy_auto(self, price_map):
 
-    def buy_auto(self, price_map):
         if self.residue < 12:
             return
+        data = self.exchange.fetch_ohlcv(symbol='BTC/BUSD', timeframe='1m', limit=60)
+        df = pd.DataFrame(data)
+        df.columns = ['timestamp', 'open', 'high', 'low', 'close', 'volume']
+        df.sort_values('timestamp', ascending=False)
+        opens = df['open'].values
+        if opens[7] < opens[1]:
+            return
+
         try:
             self.buy_market("BTC/BUSD", 12)
             logger.info("buy BTC/BUSD success")
         except Exception as e:
             return
 
-    def sell_auto(self, price_map):
+    async def sell_auto(self, price_map):
         print(price_map)
         for row in json.loads(self.strategy_df.to_json(orient='records')):
             try:
@@ -82,7 +101,10 @@ class Strategy2Task(BaseTask):
     def sell_market(self, id, symbol, amount):
         logger.info(f"sell {symbol}")
 
-        sell_json = self.exchange.create_order(symbol, 'market', 'sell', amount)
+        try:
+            sell_json = self.exchange.create_order(symbol, 'market', 'sell', amount)
+        except Exception as e:
+            sell_json = {}
         value = {
             "id": id,
             "status": 3,
@@ -107,25 +129,11 @@ class Strategy2Task(BaseTask):
                 price_map = {}
                 for sym in trades.keys():
                     price_map[sym] = float(trades[sym][-1]['info']['p'])
-                self.buy_auto(price_map)
-                self.sell_auto(price_map)
+                await self.buy_auto(price_map)
+                await self.sell_auto(price_map)
                 await exchange.sleep(10000)
             except Exception as e:
                 print(e)
 
     def run_job(self):
         run(self.watch_symbol())
-
-    def test(self):
-
-        data = self.exchange.fetch_ohlcv(symbol='BTC/BUSD', timeframe='1m',limit=60)
-        df=pd.DataFrame(data)
-        df.columns = ['timestamp','open', 'high', 'low', 'close' ,  'volume']
-        df.sort_values('timestamp',ascending=False)
-        
-        print(df[7])
-
-
-
-
-Strategy2Task().test()
